@@ -4,10 +4,10 @@ from typing import Any, Dict, List, Optional
 
 import trampolim._build
 
-from trampolim._build import ConfigurationError, TrampolimError  # noqa: F401
+from trampolim._build import ConfigurationError, TrampolimError, TrampolimWarning  # noqa: F401
 
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 # get_requires
 
